"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const utils_1 = require("./utils");
exports.isRelease = (context) => 'release' === context.eventName;
exports.isPush = (context) => 'push' === context.eventName;
exports.isPr = (context) => 'pull_request' === context.eventName;
exports.isIssue = (context) => 'issues' === context.eventName;
exports.isCron = (context) => 'schedule' === context.eventName;
exports.getTagName = (context) => exports.isRelease(context) ? context.payload.release.tag_name : (/^refs\/tags\//.test(context.ref) ? context.ref.replace(/^refs\/tags\//, '') : '');
exports.getSender = (context) => context.payload.sender && context.payload.sender.type === 'User' ? context.payload.sender.login : false;
exports.getRepository = (context) => `${context.repo.owner}/${context.repo.repo}`;
exports.getGitUrl = (context, accessTokenRequired = true) => {
    const token = utils_1.getAccessToken(accessTokenRequired);
    if (token) {
        return `https://${utils_1.getActor()}:${token}@github.com/${context.repo.owner}/${context.repo.repo}.git`;
    }
    else {
        return `https://github.com/${context.repo.owner}/${context.repo.repo}.git`;
    }
};
exports.showActionInfo = (rootDir, logger, context) => {
    const info = utils_1.getBuildInfo(path_1.default.resolve(rootDir, 'build.json'));
    const tagName = exports.getTagName(context);
    logger.log();
    logger.log('==================================================');
    if (false !== info) {
        if ('owner' in info) {
            logger.log('Version:  %s/%s@%s', info.owner, info.repo, info.tagName);
        }
        else {
            logger.log('Version:  %s', info.tagName);
        }
    }
    logger.log('Event:    %s', context.eventName);
    logger.log('Action:   %s', context.payload.action);
    logger.log('sha:      %s', context.sha);
    logger.log('ref:      %s', context.ref);
    if (tagName) {
        logger.log('Tag name: %s', tagName);
    }
    if (context.payload.issue) {
        logger.log('Labels:');
        context.payload.issue.labels.map(label => label.name).forEach(label => logger.log('  - %s', label));
    }
    if (context.payload.pull_request) {
        logger.log('Labels:');
        context.payload.pull_request.labels.map(label => label.name).forEach(label => logger.log('  - %s', label));
    }
    logger.log('owner:    %s', context.repo.owner);
    logger.log('repo:     %s', context.repo.repo);
    logger.log();
    logger.startProcess('Dump context');
    console.log(context);
    logger.startProcess('Dump Payload');
    console.log(context.payload);
    logger.endProcess();
    logger.log('==================================================');
    logger.log();
};
